==> zhongyan-activity-service-api-1.0.3-20211201.094354-78-sources.jar: cn/com/duiba/zhongyan/activity/service/api/param/OptionParam.java <==
package cn.com.duiba.zhongyan.activity.service.api.param;

/**
 * @author LuHui
 * @description
 * @date 2021/11/27  09:42
 */
public class OptionParam {

    /**
     * 例如:A,B,C,D
     */
    private String optionId;

    /**
     * 选项内容
     */
    private String optionContent;

    /**
     * 允许填空 (0允许 1不允许)
     */
    private Integer allowWrite;

    /**
     * 提示语
     */
    private String optionTip;

    /**
     * 选项图片
     */
    private String optionImage;

    /**
     * 选项必填状态（0 必填 1不必填）
     */
    private Integer tipStatus;

    public String getOptionId() {
        return optionId;
    }

    public void setOptionId(String optionId) {
        this.optionId = optionId;
    }

    public String getOptionContent() {
        return optionContent;
    }

    public void setOptionContent(String optionContent) {
        this.optionContent = optionContent;
    }

    public Integer getAllowWrite() {
        return allowWrite;
    }

    public void setAllowWrite(Integer allowWrite) {
        this.allowWrite = allowWrite;
    }

    public String getOptionTip() {
        return optionTip;
    }

    public void setOptionTip(String optionTip) {
        this.optionTip = optionTip;
    }

    public String getOptionImage() {
        return optionImage;
    }

    public void setOptionImage(String optionImage) {
        this.optionImage = optionImage;
    }

    public Integer getTipStatus() {
        return tipStatus;
    }

    public void setTipStatus(Integer tipStatus) {
        this.tipStatus = tipStatus;
    }
}

==> zhongyan-activity-service-api-2.0.5-sources.jar: cn/com/duiba/zhongyan/activity/service/api/param/OptionParam.java <==
package cn.com.duiba.zhongyan.activity.service.api.param;

import java.io.Serializable;

/**
 * @author LuHui
 * @description
 * @date 2021/11/27  09:42
 */
public class OptionParam implements Serializable {

    private static final long serialVersionUID = 8251321415085505455L;
    /**
     * 例如:A,B,C,D
     */
    private String optionId;

    /**
     * 选项内容
     */
    private String optionContent;

    /**
     * 允许填空 (0允许 1不允许)
     */
    private Integer allowWrite;

    /**
     * 提示语
     */
    private String optionTip;

    /**
     * 选项图片
     */
    private String optionImage;

    /**
     * 选项必填状态（0 必填 1不必填）
     */
    private Integer tipStatus;

    /**
     * 要跳转的题目id
     */
    private Integer jumpQuestionId;

    public Integer getJumpQuestionId() {
        return jumpQuestionId;
    }

    public void setJumpQuestionId(Integer jumpQuestionId) {
        this.jumpQuestionId = jumpQuestionId;
    }

    public String getOptionId() {
        return optionId;
    }

    public void setOptionId(String optionId) {
        this.optionId = optionId;
    }

    public String getOptionContent() {
        return optionContent;
    }

    public void setOptionContent(String optionContent) {
        this.optionContent = optionContent;
    }

    public Integer getAllowWrite() {
        return allowWrite;
    }

    public void setAllowWrite(Integer allowWrite) {
        this.allowWrite = allowWrite;
    }

    public String getOptionTip() {
        return optionTip;
    }

    public void setOptionTip(String optionTip) {
        this.optionTip = optionTip;
    }

    public String getOptionImage() {
        return optionImage;
    }

    public void setOptionImage(String optionImage) {
        this.optionImage = optionImage;
    }

    public Integer getTipStatus() {
        return tipStatus;
    }

    public void setTipStatus(Integer tipStatus) {
        this.tipStatus = tipStatus;
    }
}
